pilas.actores.zanahoria

Package pilas :: Package actores :: Module zanahoria |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.zanahoria

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  from pilas.actores import Actor
    11
    12 -class Zanahoria(Actor):
    13      """Representa un actor que parece una Zanahoria."""
    14
    15 -    def __init__(self, x=0, y=0):
    16          """Inicializa el actor en una posición inicial.
    17
    18          :param x: Posición horizontal inicial.
    19          :param y: Posición vertical inicial.
    20          """
    21          self.cuadro_normal = pilas.imagenes.cargar("zanahoria_normal.png")
    22          self.cuadro_reir = pilas.imagenes.cargar("zanahoria_sonrie.png")
    23
    24          Actor.__init__(self, x=x, y=y)
    25          self.normal()
    26          self.radio_de_colision = 25
    27
    28 -    def normal(self):
    29          """Cambia la imagen actual por una donde se ve la zanahora normal."""
    30          self.imagen = self.cuadro_normal
    31          self.centro = ('centro', 65)
    32
    33 -    def sonreir(self):
    34          """Cambia la imagen actual por una en donde tiene una sonrisa"""
    35          self.imagen = self.cuadro_reir
    36          self.centro = ('centro', 65)
    37
    38 -    def saltar(self):
    39          """Realiza un salto hacia arriba."""
    40          self.sonreir()
    41          accion = pilas.comportamientos.Saltar(cuando_termina=self.normal)
    42          self.hacer(accion)
    43
    44 -    def decir(self, mensaje):
    45          """Emite un mensaje usando un globo similar al de los commics.
    46
    47          :param mensaje: La cadena de mensaje que mostrará."""
    48          self.sonreir()
    49          Actor.decir(self, mensaje)
    50          pilas.mundo.agregar_tarea_una_vez(1, self.normal)
    51